@@ -3,11 +3,15 @@ var NAVTREEINDEX0 =
 "index.html":[],
 "index.html":[0],
 "index.html#freetds_binding_by_value":[0,4,0,1],
-"index.html#sybase_103":[0,6,1],
-"index.html#sybase_104":[0,6,0],
+"index.html#sybase_103":[0,6,4],
+"index.html#sybase_104":[0,6,3],
+"index.html#sybase_1041":[0,6,2],
+"index.html#sybase_1042":[0,6,1],
+"index.html#sybase_1_1":[0,6,0],
 "index.html#sybase_and_freetds_binding_by_value":[0,4,0],
 "index.html#sybase_binding_by_value":[0,4,0,0],
 "index.html#sybase_number_options":[0,1,0],
+"index.html#sybase_statements":[0,0,0],
 "index.html#sybase_timezone":[0,3],
 "index.html#sybase_to_qore":[0,4,1],
 "index.html#sybasebind":[0,4],
